@@ -6,7 +6,7 @@ use Carp;
 use POSIX ();
 use Pegex::Base; # use this instead of Mo
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 $VERSION = eval $VERSION;
 
 has type => 'p16f690';
@@ -2839,7 +2839,7 @@ sub pwm_details {
     my $pstrcon = sprintf "b'0001%d%d%d%d'", $str{P1D}, $str{P1C}, $str{P1B}, $str{P1A};
     my $trisc_bsf = '';
     my $trisc_bcf = '';
-    foreach (keys %trisc) {
+    foreach (sort (keys %trisc)) {
         $trisc_bsf .= "\tbsf TRISC, TRISC$_\n";
         $trisc_bcf .= "\tbcf TRISC, TRISC$_\n";
     }
